@@ -78,7 +78,7 @@ class GCSFS(FS):
         if retry:
             adapter = HTTPAdapter(max_retries=Retry(total=retry,
                                                     status_forcelist=[429, 502, 503, 504],
-                                                    method_whitelist=False,  # retry on any HTTP method
+                                                    allowed_methods=False,  # retry on any HTTP method
                                                     backoff_factor=0.5))
             self.client._http.mount("https://", adapter)
 
@@ -602,6 +602,10 @@ class GCSFile(io.IOBase):
     def writelines(self, lines):
         return self._f.writelines(lines)
 
+    @property
+    def mode(self):
+        return self.__mode.to_platform_bin()
+
     def read(self, n=-1):
         if not self.__mode.reading:
             raise IOError("not open for reading")
@@ -611,7 +615,7 @@ class GCSFile(io.IOBase):
         return self._f.readall()
 
     def readinto(self, b):
-        return self._f.readinto()
+        return self._f.readinto(b)
 
     def write(self, b):
         if not self.__mode.writing:
